@@ -1,8 +1,22 @@
 ############################ Copyrights and license ############################
 #                                                                              #
+# Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2012 Zearin <zearin@gonk.net>                                      #
+# Copyright 2013 AKFish <akfish@gmail.com>                                     #
+# Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2016 Jannis Gebauer <ja.geb@me.com>                                #
+# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
 # Copyright 2017 Jannis Gebauer <ja.geb@me.com>                                #
 # Copyright 2017 Simon <spam@esemi.ru>                                         #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2019 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2021 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -22,106 +36,88 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import annotations
+
+from datetime import datetime
+from typing import TYPE_CHECKING, Any
+
 import github.GithubObject
+import github.NamedUser
+import github.Repository
+from github.GithubObject import Attribute, CompletableGithubObject, NotSet
+
+if TYPE_CHECKING:
+    from github.NamedUser import NamedUser
+    from github.Repository import Repository
 
 
-class Invitation(github.GithubObject.CompletableGithubObject):
+class Invitation(CompletableGithubObject):
     """
     This class represents repository invitations. The reference can be found here https://docs.github.com/en/rest/reference/repos#invitations
     """
 
-    def __repr__(self):
+    def _initAttributes(self) -> None:
+        self._id: Attribute[int] = NotSet
+        self._permissions: Attribute[str] = NotSet
+        self._created_at: Attribute[datetime] = NotSet
+        self._invitee: Attribute[NamedUser] = NotSet
+        self._inviter: Attribute[NamedUser] = NotSet
+        self._url: Attribute[str] = NotSet
+        self._html_url: Attribute[str] = NotSet
+        self._repository: Attribute[Repository] = NotSet
+
+    def __repr__(self) -> str:
         return self.get__repr__({"id": self._id.value})
 
     @property
-    def id(self):
-        """
-        :type: integer
-        """
+    def id(self) -> int:
         self._completeIfNotSet(self._id)
         return self._id.value
 
     @property
-    def permissions(self):
-        """
-        :type: string
-        """
+    def permissions(self) -> str:
         self._completeIfNotSet(self._permissions)
         return self._permissions.value
 
     @property
-    def created_at(self):
-        """
-        :type: string
-        """
+    def created_at(self) -> datetime:
         self._completeIfNotSet(self._created_at)
         return self._created_at.value
 
     @property
-    def invitee(self):
-        """
-        :type: NamedUser
-        """
+    def invitee(self) -> NamedUser:
         self._completeIfNotSet(self._invitee)
         return self._invitee.value
 
     @property
-    def inviter(self):
-        """
-        :type: NamedUser
-        """
+    def inviter(self) -> NamedUser:
         self._completeIfNotSet(self._inviter)
         return self._inviter.value
 
     @property
-    def url(self):
-        """
-        :type: string
-        """
+    def url(self) -> str:
         self._completeIfNotSet(self._url)
         return self._url.value
 
     @property
-    def html_url(self):
-        """
-        :type: string
-        """
+    def html_url(self) -> str:
         self._completeIfNotSet(self._html_url)
         return self._html_url.value
 
     @property
-    def repository(self):
-        """
-        :type: Repository
-        """
+    def repository(self) -> Repository:
         self._completeIfNotSet(self._repository)
         return self._repository.value
 
-    def _initAttributes(self):
-        self._id = github.GithubObject.NotSet
-        self._permissions = github.GithubObject.NotSet
-        self._created_at = github.GithubObject.NotSet
-        self._invitee = github.GithubObject.NotSet
-        self._inviter = github.GithubObject.NotSet
-        self._url = github.GithubObject.NotSet
-        self._html_url = github.GithubObject.NotSet
-        self._repository = github.GithubObject.NotSet
-
-    def _useAttributes(self, attributes):
+    def _useAttributes(self, attributes: dict[str, Any]) -> None:
         if "repository" in attributes:  # pragma no branch
-            self._repository = self._makeClassAttribute(
-                github.Repository.Repository, attributes["repository"]
-            )
+            self._repository = self._makeClassAttribute(github.Repository.Repository, attributes["repository"])
         if "created_at" in attributes:  # pragma no branch
             self._created_at = self._makeDatetimeAttribute(attributes["created_at"])
         if "invitee" in attributes:  # pragma no branch
-            self._invitee = self._makeClassAttribute(
-                github.NamedUser.NamedUser, attributes["invitee"]
-            )
+            self._invitee = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["invitee"])
         if "inviter" in attributes:  # pragma no branch
-            self._inviter = self._makeClassAttribute(
-                github.NamedUser.NamedUser, attributes["inviter"]
-            )
+            self._inviter = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["inviter"])
         if "id" in attributes:  # pragma no branch
             self._id = self._makeIntAttribute(attributes["id"])
 
